.. module:: cobyqa.problem

Optimization problem
====================

This module implements classes for representing optimization problems for COBYQA.

.. currentmodule:: cobyqa.problem

.. autosummary::
    :toctree: generated/

    ObjectiveFunction
    BoundConstraints
    LinearConstraints
    NonlinearConstraints
    Problem
